import autoscaling = require('@aws-cdk/aws-autoscaling');
import cdk = require('@aws-cdk/cdk');
import { ICluster } from '../cluster';
/**
 * Properties for instance draining hook
 */
export interface InstanceDrainHookProps {
    /**
     * The AutoScalingGroup to install the instance draining hook for
     */
    autoScalingGroup: autoscaling.IAutoScalingGroup;
    /**
     * The cluster on which tasks have been scheduled
     */
    cluster: ICluster;
    /**
     * How many seconds to give tasks to drain before the instance is terminated anyway
     *
     * Must be between 0 and 900.
     *
     * @default 900
     */
    drainTimeSec?: number;
}
/**
 * A hook to drain instances from ECS traffic before they're terminated
 */
export declare class InstanceDrainHook extends cdk.Construct {
    constructor(scope: cdk.Construct, id: string, props: InstanceDrainHookProps);
}
