import { Construct } from '@aws-cdk/cdk';
import { CommonTaskDefinitionProps, ITaskDefinition, NetworkMode, TaskDefinition } from '../base/task-definition';
import { PlacementConstraint } from '../placement';
/**
 * Properties to define an ECS task definition
 */
export interface Ec2TaskDefinitionProps extends CommonTaskDefinitionProps {
    /**
     * The Docker networking mode to use for the containers in the task.
     *
     * On Fargate, the only supported networking mode is AwsVpc.
     *
     * @default - NetworkMode.Bridge for EC2 tasks, AwsVpc for Fargate tasks.
     */
    readonly networkMode?: NetworkMode;
    /**
     * An array of placement constraint objects to use for the task. You can
     * specify a maximum of 10 constraints per task (this limit includes
     * constraints in the task definition and those specified at run time).
     *
     * Not supported in Fargate.
     *
     * @default - No placement constraints.
     */
    readonly placementConstraints?: PlacementConstraint[];
}
export interface IEc2TaskDefinition extends ITaskDefinition {
}
/**
 * Define Tasks to run on an ECS cluster
 *
 * @resource AWS::ECS::TaskDefinition
 */
export declare class Ec2TaskDefinition extends TaskDefinition implements IEc2TaskDefinition {
    static fromEc2TaskDefinitionArn(scope: Construct, id: string, ec2TaskDefinitionArn: string): IEc2TaskDefinition;
    constructor(scope: Construct, id: string, props?: Ec2TaskDefinitionProps);
}
